import { DismissableElementHandlers, PersistentElementOptions } from '@zag-js/dismissable';
export { FocusOutsideEvent, InteractOutsideEvent, PointerDownOutsideEvent } from '@zag-js/dismissable';
import * as _zag_js_anatomy from '@zag-js/anatomy';
import { RequiredBy, PropTypes, CommonProperties, DirectionProperty, NormalizeProps } from '@zag-js/types';
import * as _zag_js_core from '@zag-js/core';
import { StateMachine } from '@zag-js/core';
import { PositioningOptions } from '@zag-js/popper';
export { Placement, PositioningOptions } from '@zag-js/popper';

declare const anatomy: _zag_js_anatomy.AnatomyInstance<"title" | "anchor" | "description" | "content" | "arrow" | "arrowTip" | "trigger" | "indicator" | "positioner" | "closeTrigger">;

interface OpenChangeDetails {
    open: boolean;
}
type ElementIds = Partial<{
    anchor: string;
    trigger: string;
    content: string;
    title: string;
    description: string;
    closeTrigger: string;
    positioner: string;
    arrow: string;
}>;
interface PublicContext extends CommonProperties, DirectionProperty, DismissableElementHandlers, PersistentElementOptions {
    /**
     * The ids of the elements in the popover. Useful for composition.
     */
    ids?: ElementIds;
    /**
     * Whether the popover should be modal. When set to `true`:
     * - interaction with outside elements will be disabled
     * - only popover content will be visible to screen readers
     * - scrolling is blocked
     * - focus is trapped within the popover
     *
     * @default false
     */
    modal?: boolean;
    /**
     * Whether the popover is portalled. This will proxy the tabbing behavior regardless of the DOM position
     * of the popover content.
     *
     * @default true
     */
    portalled?: boolean;
    /**
     * Whether to automatically set focus on the first focusable
     * content within the popover when opened.
     *
     * @default true
     */
    autoFocus?: boolean;
    /**
     * The element to focus on when the popover is opened.
     */
    initialFocusEl?: () => HTMLElement | null;
    /**
     * Whether to close the popover when the user clicks outside of the popover.
     * @default true
     */
    closeOnInteractOutside?: boolean;
    /**
     * Whether to close the popover when the escape key is pressed.
     * @default true
     */
    closeOnEscape?: boolean;
    /**
     * Function invoked when the popover opens or closes
     */
    onOpenChange?: (details: OpenChangeDetails) => void;
    /**
     * The user provided options used to position the popover content
     */
    positioning: PositioningOptions;
    /**
     * Whether the popover is open
     */
    open?: boolean;
    /**
     * Whether the popover is controlled by the user
     */
    "open.controlled"?: boolean;
}
type UserDefinedContext = RequiredBy<PublicContext, "id">;
type ComputedContext = Readonly<{
    /**
     * @computed
     * The computed value of `portalled`
     */
    currentPortalled: boolean;
}>;
interface PrivateContext {
}
interface MachineContext extends PublicContext, ComputedContext, PrivateContext {
}
interface MachineState {
    value: "open" | "closed";
}
type State = StateMachine.State<MachineContext, MachineState>;
type Send = StateMachine.Send<StateMachine.AnyEventObject>;
interface MachineApi<T extends PropTypes = PropTypes> {
    /**
     * Whether the popover is portalled.
     */
    portalled: boolean;
    /**
     * Whether the popover is open
     */
    open: boolean;
    /**
     * Function to open or close the popover
     */
    setOpen(open: boolean): void;
    /**
     * Function to reposition the popover
     */
    reposition(options?: Partial<PositioningOptions>): void;
    arrowProps: T["element"];
    arrowTipProps: T["element"];
    anchorProps: T["element"];
    triggerProps: T["button"];
    indicatorProps: T["element"];
    positionerProps: T["element"];
    contentProps: T["element"];
    titleProps: T["element"];
    descriptionProps: T["element"];
    closeTriggerProps: T["button"];
}

declare function connect<T extends PropTypes>(state: State, send: Send, normalize: NormalizeProps<T>): MachineApi<T>;

declare function machine(userContext: UserDefinedContext): _zag_js_core.Machine<MachineContext, MachineState, _zag_js_core.StateMachine.AnyEventObject>;

declare const props: ("dir" | "id" | "getRootNode" | "open" | "autoFocus" | "onFocusOutside" | "onPointerDownOutside" | "onInteractOutside" | "onEscapeKeyDown" | "ids" | "modal" | "portalled" | "initialFocusEl" | "closeOnInteractOutside" | "closeOnEscape" | "onOpenChange" | "positioning" | "open.controlled" | "persistentElements")[];
declare const splitProps: <Props extends Partial<UserDefinedContext>>(props: Props) => [Partial<UserDefinedContext>, Omit<Props, "dir" | "id" | "getRootNode" | "open" | "autoFocus" | "onFocusOutside" | "onPointerDownOutside" | "onInteractOutside" | "onEscapeKeyDown" | "ids" | "modal" | "portalled" | "initialFocusEl" | "closeOnInteractOutside" | "closeOnEscape" | "onOpenChange" | "positioning" | "open.controlled" | "persistentElements">];

export { type MachineApi as Api, type UserDefinedContext as Context, type ElementIds, type OpenChangeDetails, anatomy, connect, machine, props, splitProps };
